import setuptools
from distutils.core import setup
setup(
  name = 'heat',
  packages = ['heat'],
  version = '0.0.0',
  description = 'A framework for high performace data analytics and machine learning.',
  author = 'Helmholtz Association',
  author_email = 'martin.siggel@dlr.de',
#  url = 'https://github.com/peterldowns/mypackage', # use the URL to the github repo
#  download_url = 'https://github.com/peterldowns/mypackage/archive/0.1.tar.gz', # I'll explain this in a second
  keywords = ['data', 'analytics', 'tensors', 'distributed', 'gpu'], # arbitrary keywords
  classifiers = [],
)